import type { ISystemInfo, Env, StandardResponse } from '@jolibox/types';
/**
 * @public
 * Synchronously retrieves system information.
 * The specific structure of the returned system information object depends on the Jolibox environment.
 * @returns {StandardResponse<ISystemInfo>} An object containing system information, wrapped in a StandardResponse.
 * @see {@link ISystemInfo}
 * @type {ISystemInfo}
 * check IsystemInfo for more details
 */
export declare function getSystemInfoSync(): StandardResponse<ISystemInfo>;
/**
 * @public
 * Synchronously retrieves environment-specific information.
 * This can include details about the host environment, application versions, etc., excluding 'hostUserInfo' and 'schema' from the full Env type.
 * @returns {StandardResponse<Omit<Omit<Env, 'hostUserInfo'>, 'schema'>>} An object containing filtered environment information, wrapped in a StandardResponse.
 * @see {@link Env}
 * @type {Omit<Omit<Env, 'hostUserInfo'>, 'schema'>}
 * check Env for more details
 * @example
 * ```typescript
 * const envInfo = getEnvSync();
 * console.log(envInfo);
 * ```
 */
export declare function env(): StandardResponse<Omit<Omit<Env, 'hostUserInfo'>, 'schema'>>;
